summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgamepropertyhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/kgamepropertyhandler.h')
-rw-r--r--libkdegames/kgame/kgamepropertyhandler.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/libkdegames/kgame/kgamepropertyhandler.h b/libkdegames/kgame/kgamepropertyhandler.h
index 6147c071..ec7fec06 100644
--- a/libkdegames/kgame/kgamepropertyhandler.h
+++ b/libkdegames/kgame/kgamepropertyhandler.h
@@ -21,8 +21,8 @@
#ifndef __KGAMEPROPERTYHANDLER_H_
#define __KGAMEPROPERTYHANDLER_H_
-#include <qobject.h>
-#include <qintdict.h>
+#include <tqobject.h>
+#include <tqintdict.h>
#include "kgameproperty.h"
#include <kdemacros.h>
@@ -63,7 +63,7 @@ class KGamePropertyHandlerPrivate; // wow - what a name ;-)
*
* A KGamePropertyHandler is also used - indirectly using emitSignal - to
* emit a signal when the value of a property changes. This is done this way
* because a KGameProperty does not inherit QObject because of memory
* advantages. Many games can have dozens or even hundreds of KGameProperty
* objects so every additional variable in KGameProperty would be
* multiplied.
@@ -80,14 +80,14 @@ public:
* You have to call registerHandler before you can use this
* handler!
**/
- KGamePropertyHandler(QObject* parent = 0);
+ KGamePropertyHandler(TQObject* parent = 0);
/**
* Construct a registered handler.
*
* @see registerHandler
**/
- KGamePropertyHandler(int id, const QObject* receiver, const char* sendf, const char* emitf, QObject* parent = 0);
+ KGamePropertyHandler(int id, const TQObject* receiver, const char* sendf, const char* emitf, TQObject* parent = 0);
~KGamePropertyHandler();
/**
@@ -101,7 +101,7 @@ public:
* @param send A slot that is being connected to signalSendMessage
* @param emit A slot that is being connected to signalPropertyChanged
**/
- void registerHandler(int id, const QObject *receiver, const char * send, const char *emit);
+ void registerHandler(int id, const TQObject *receiver, const char * send, const char *emit);
/**
* Main message process function. This has to be called by
@@ -118,7 +118,7 @@ public:
* @param isSender Whether the receiver is also the sender
* @return true on message processed otherwise false
**/
- bool processMessage(QDataStream &stream, int id, bool isSender );
+ bool processMessage(TQDataStream &stream, int id, bool isSender );
/**
* @return the id of the handler
@@ -132,7 +132,7 @@ public:
* propertyName. This is used for debugging, e.g. in KGameDebugDialog
* @return true on success
**/
- bool addProperty(KGamePropertyBase *data, QString name=0);
+ bool addProperty(KGamePropertyBase *data, TQString name=0);
/**
* Removes a property from the handler
@@ -156,7 +156,7 @@ public:
* @param stream the datastream to load from
* @return true on success otherwise false
**/
- virtual bool load(QDataStream &stream);
+ virtual bool load(TQDataStream &stream);
/**
* Saves properties into the datastream
@@ -164,14 +164,14 @@ public:
* @param stream the datastream to save to
* @return true on success otherwise false
**/
- virtual bool save(QDataStream &stream);
+ virtual bool save(TQDataStream &stream);
/**
* called by a property to send itself into the
* datastream. This call is simply forwarded to
* the parent object
**/
- bool sendProperty(QDataStream &s);
+ bool sendProperty(TQDataStream &s);
void sendLocked(bool l);
@@ -188,7 +188,7 @@ public:
* depend on this function! It it possible not to provide a name or to
* provide the same name for multiple properties!
**/
- QString propertyName(int id) const;
+ TQString propertyName(int id) const;
/**
* @param id The ID of the property. See KGamePropertyBase::id
@@ -277,13 +277,13 @@ public:
/**
* Reference to the internal dictionary
**/
- QIntDict<KGamePropertyBase> &dict() const;
+ TQIntDict<KGamePropertyBase> &dict() const;
/**
* In several situations you just want to have a QString of a
* KGameProperty object. This is the case in the
* KGameDebugDialog where the value of all properties is displayed. This
* function will provide you with such a QString for all the types
* used inside of all KGame classes. If you have a non-standard
* property (probably a self defined class or something like this) you
* also need to connect to signalRequestValue to make this function
@@ -291,7 +291,7 @@ public:
* @param property Return the value of this KGameProperty
* @return The value of a KGameProperty
**/
- QString propertyValue(KGamePropertyBase* property);
+ TQString propertyValue(KGamePropertyBase* property);
/**
@@ -320,20 +320,20 @@ signals:
* @param sent set this to true if the property was sent successfully -
* otherwise don't touch
**/
- void signalSendMessage(int msgid, QDataStream &, bool* sent); // AB shall we change bool* into bool& again?
+ void signalSendMessage(int msgid, TQDataStream &, bool* sent); // AB shall we change bool* into bool& again?
/**
* If you call propertyValue with a non-standard KGameProperty
* it is possible that the value cannot automatically be converted into a
* QString. Then this signal is emitted and asks you to provide the
* correct value. You probably want to use something like this to achieve
* this:
* \code
* #include <typeinfo>
- * void slotRequestValue(KGamePropertyBase* p, QString& value)
+ * void slotRequestValue(KGamePropertyBase* p, TQString& value)
* {
* if (*(p->typeinfo()) == typeid(MyType) {
- * value = QString(((KGameProperty<MyType>*)p)->value());
+ * value = TQString(((KGameProperty<MyType>*)p)->value());
* }
* }
* \endcode
@@ -341,7 +341,7 @@ signals:
* @param property The KGamePropertyBase the value is requested for
* @param value The value of this property. You have to set this.
**/
- void signalRequestValue(KGamePropertyBase* property, QString& value);
+ void signalRequestValue(KGamePropertyBase* property, TQString& value);
private:
void init();
@@ -63,7 +63,7 @@ class KGamePropertyHandlerPrivate; // wow - what a name ;-)
* A KGamePropertyHandler is also used - indirectly using emitSignal - to
* emit a signal when the value of a property changes. This is done this way
- * because a KGameProperty does not inherit QObject because of memory
+ * because a KGameProperty does not inherit TQObject because of memory
* advantages. Many games can have dozens or even hundreds of KGameProperty
* objects so every additional variable in KGameProperty would be
@@ -277,13 +277,13 @@ public:
/**
- * In several situations you just want to have a QString of a
+ * In several situations you just want to have a TQString of a
* KGameProperty object. This is the case in the
* KGameDebugDialog where the value of all properties is displayed. This
@@ -277,13 +277,13 @@ public:
* KGameProperty object. This is the case in the
* KGameDebugDialog where the value of all properties is displayed. This
- * function will provide you with such a QString for all the types
+ * function will provide you with such a TQString for all the types
* used inside of all KGame classes. If you have a non-standard
* property (probably a self defined class or something like this) you
@@ -320,20 +320,20 @@ signals:
* If you call propertyValue with a non-standard KGameProperty
* it is possible that the value cannot automatically be converted into a
- * QString. Then this signal is emitted and asks you to provide the
+ * TQString. Then this signal is emitted and asks you to provide the
* correct value. You probably want to use something like this to achieve
* this: